@@ -72,7 +72,7 @@
 //!     let mut sda = Pin::new(Port::B, 7, PinMode::Alt(4));
 //!     sda.output_type(OutputType::OpenDrain);
 //!
-//!     let i2c = I2c::new(dp.I2C1, I2cDevice::One, 100_000, &clock_cfg);
+//!     let i2c = I2c::new(dp.I2C1, I2cDevice::One, Default::default(), &clock_cfg);
 //!
 //!     loop {
 //!         i2c.write(0x50, &[1, 2, 3]);
@@ -367,7 +367,7 @@ pub mod dma;
 
 #[cfg(not(feature = "h7"))] // todo
 pub mod flash;
-#[cfg(not(feature = "wl"))] // todo
+
 pub mod gpio;
 
 #[cfg(feature = "wb")]
@@ -407,7 +407,6 @@ feature = "wl",
 )))]
 pub mod qspi;
 
-#[cfg(not(feature = "wl"))] // todo
 pub mod rtc;
 
 #[cfg(not(any(
@@ -421,10 +420,8 @@ pub mod rtc;
 pub mod sai;
 
 pub mod spi;
-
-#[cfg(not(feature = "wl"))] // todo
+// #[cfg(not(feature = "wl"))] // todo
 pub mod timer;
-#[cfg(not(feature = "wl"))] // todo
 pub mod usart;
 
 // See note at top of `usb` module for info on G0; not avail on modules the PAC has avail.
